# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.cosmos.base.node.v1beta1 import query_pb2 as cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2


class ServiceStub(object):
    """Service defines the gRPC querier service for node related queries.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Config = channel.unary_unary(
                '/cosmos.base.node.v1beta1.Service/Config',
                request_serializer=cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.ConfigRequest.SerializeToString,
                response_deserializer=cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.ConfigResponse.FromString,
                )
        self.Status = channel.unary_unary(
                '/cosmos.base.node.v1beta1.Service/Status',
                request_serializer=cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.StatusRequest.SerializeToString,
                response_deserializer=cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.StatusResponse.FromString,
                )


class ServiceServicer(object):
    """Service defines the gRPC querier service for node related queries.
    """

    def Config(self, request, context):
        """Config queries for the operator configuration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Status(self, request, context):
        """Status queries for the node status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Config': grpc.unary_unary_rpc_method_handler(
                    servicer.Config,
                    request_deserializer=cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.ConfigRequest.FromString,
                    response_serializer=cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.ConfigResponse.SerializeToString,
            ),
            'Status': grpc.unary_unary_rpc_method_handler(
                    servicer.Status,
                    request_deserializer=cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.StatusRequest.FromString,
                    response_serializer=cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.StatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.base.node.v1beta1.Service', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Service(object):
    """Service defines the gRPC querier service for node related queries.
    """

    @staticmethod
    def Config(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.base.node.v1beta1.Service/Config',
            cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.ConfigRequest.SerializeToString,
            cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.ConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Status(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.base.node.v1beta1.Service/Status',
            cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.StatusRequest.SerializeToString,
            cosmos_dot_base_dot_node_dot_v1beta1_dot_query__pb2.StatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.cosmos.circuit.v1 import tx_pb2 as cosmos_dot_circuit_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the circuit Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AuthorizeCircuitBreaker = channel.unary_unary(
                '/cosmos.circuit.v1.Msg/AuthorizeCircuitBreaker',
                request_serializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgAuthorizeCircuitBreaker.SerializeToString,
                response_deserializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgAuthorizeCircuitBreakerResponse.FromString,
                )
        self.TripCircuitBreaker = channel.unary_unary(
                '/cosmos.circuit.v1.Msg/TripCircuitBreaker',
                request_serializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgTripCircuitBreaker.SerializeToString,
                response_deserializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgTripCircuitBreakerResponse.FromString,
                )
        self.ResetCircuitBreaker = channel.unary_unary(
                '/cosmos.circuit.v1.Msg/ResetCircuitBreaker',
                request_serializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgResetCircuitBreaker.SerializeToString,
                response_deserializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgResetCircuitBreakerResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the circuit Msg service.
    """

    def AuthorizeCircuitBreaker(self, request, context):
        """AuthorizeCircuitBreaker allows a super-admin to grant (or revoke) another
        account's circuit breaker permissions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TripCircuitBreaker(self, request, context):
        """TripCircuitBreaker pauses processing of Msg's in the state machine.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetCircuitBreaker(self, request, context):
        """ResetCircuitBreaker resumes processing of Msg's in the state machine that
        have been been paused using TripCircuitBreaker.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AuthorizeCircuitBreaker': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthorizeCircuitBreaker,
                    request_deserializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgAuthorizeCircuitBreaker.FromString,
                    response_serializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgAuthorizeCircuitBreakerResponse.SerializeToString,
            ),
            'TripCircuitBreaker': grpc.unary_unary_rpc_method_handler(
                    servicer.TripCircuitBreaker,
                    request_deserializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgTripCircuitBreaker.FromString,
                    response_serializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgTripCircuitBreakerResponse.SerializeToString,
            ),
            'ResetCircuitBreaker': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetCircuitBreaker,
                    request_deserializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgResetCircuitBreaker.FromString,
                    response_serializer=cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgResetCircuitBreakerResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.circuit.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the circuit Msg service.
    """

    @staticmethod
    def AuthorizeCircuitBreaker(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.circuit.v1.Msg/AuthorizeCircuitBreaker',
            cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgAuthorizeCircuitBreaker.SerializeToString,
            cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgAuthorizeCircuitBreakerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TripCircuitBreaker(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.circuit.v1.Msg/TripCircuitBreaker',
            cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgTripCircuitBreaker.SerializeToString,
            cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgTripCircuitBreakerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetCircuitBreaker(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.circuit.v1.Msg/ResetCircuitBreaker',
            cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgResetCircuitBreaker.SerializeToString,
            cosmos_dot_circuit_dot_v1_dot_tx__pb2.MsgResetCircuitBreakerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.dydxprotocol.delaymsg import query_pb2 as dydxprotocol_dot_delaymsg_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.NextDelayedMessageId = channel.unary_unary(
                '/dydxprotocol.delaymsg.Query/NextDelayedMessageId',
                request_serializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryNextDelayedMessageIdRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryNextDelayedMessageIdResponse.FromString,
                )
        self.Message = channel.unary_unary(
                '/dydxprotocol.delaymsg.Query/Message',
                request_serializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryMessageRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryMessageResponse.FromString,
                )
        self.BlockMessageIds = channel.unary_unary(
                '/dydxprotocol.delaymsg.Query/BlockMessageIds',
                request_serializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryBlockMessageIdsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryBlockMessageIdsResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def NextDelayedMessageId(self, request, context):
        """Queries the next DelayedMessage's id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Message(self, request, context):
        """Queries the DelayedMessage by id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BlockMessageIds(self, request, context):
        """Queries the DelayedMessages at a given block height.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'NextDelayedMessageId': grpc.unary_unary_rpc_method_handler(
                    servicer.NextDelayedMessageId,
                    request_deserializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryNextDelayedMessageIdRequest.FromString,
                    response_serializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryNextDelayedMessageIdResponse.SerializeToString,
            ),
            'Message': grpc.unary_unary_rpc_method_handler(
                    servicer.Message,
                    request_deserializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryMessageRequest.FromString,
                    response_serializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryMessageResponse.SerializeToString,
            ),
            'BlockMessageIds': grpc.unary_unary_rpc_method_handler(
                    servicer.BlockMessageIds,
                    request_deserializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryBlockMessageIdsRequest.FromString,
                    response_serializer=dydxprotocol_dot_delaymsg_dot_query__pb2.QueryBlockMessageIdsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.delaymsg.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def NextDelayedMessageId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.delaymsg.Query/NextDelayedMessageId',
            dydxprotocol_dot_delaymsg_dot_query__pb2.QueryNextDelayedMessageIdRequest.SerializeToString,
            dydxprotocol_dot_delaymsg_dot_query__pb2.QueryNextDelayedMessageIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Message(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.delaymsg.Query/Message',
            dydxprotocol_dot_delaymsg_dot_query__pb2.QueryMessageRequest.SerializeToString,
            dydxprotocol_dot_delaymsg_dot_query__pb2.QueryMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BlockMessageIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.delaymsg.Query/BlockMessageIds',
            dydxprotocol_dot_delaymsg_dot_query__pb2.QueryBlockMessageIdsRequest.SerializeToString,
            dydxprotocol_dot_delaymsg_dot_query__pb2.QueryBlockMessageIdsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.dydxprotocol.delaymsg import tx_pb2 as dydxprotocol_dot_delaymsg_dot_tx__pb2


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DelayMessage = channel.unary_unary(
                '/dydxprotocol.delaymsg.Msg/DelayMessage',
                request_serializer=dydxprotocol_dot_delaymsg_dot_tx__pb2.MsgDelayMessage.SerializeToString,
                response_deserializer=dydxprotocol_dot_delaymsg_dot_tx__pb2.MsgDelayMessageResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def DelayMessage(self, request, context):
        """DelayMessage delays the execution of a message for a given number of
        blocks.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DelayMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.DelayMessage,
                    request_deserializer=dydxprotocol_dot_delaymsg_dot_tx__pb2.MsgDelayMessage.FromString,
                    response_serializer=dydxprotocol_dot_delaymsg_dot_tx__pb2.MsgDelayMessageResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.delaymsg.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def DelayMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.delaymsg.Msg/DelayMessage',
            dydxprotocol_dot_delaymsg_dot_tx__pb2.MsgDelayMessage.SerializeToString,
            dydxprotocol_dot_delaymsg_dot_tx__pb2.MsgDelayMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc



class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.govplus.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.dydxprotocol.clob import block_rate_limit_config_pb2 as _block_rate_limit_config_pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as _clob_pair_pb2
from v4_proto.dydxprotocol.clob import equity_tier_limit_config_pb2 as _equity_tier_limit_config_pb2
from v4_proto.dydxprotocol.clob import liquidations_config_pb2 as _liquidations_config_pb2
from v4_proto.dydxprotocol.clob import mev_pb2 as _mev_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryGetClobPairRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryClobPairResponse(_message.Message):
    __slots__ = ("clob_pair",)
    CLOB_PAIR_FIELD_NUMBER: _ClassVar[int]
    clob_pair: _clob_pair_pb2.ClobPair
    def __init__(self, clob_pair: _Optional[_Union[_clob_pair_pb2.ClobPair, _Mapping]] = ...) -> None: ...

class QueryAllClobPairRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryClobPairAllResponse(_message.Message):
    __slots__ = ("clob_pair", "pagination")
    CLOB_PAIR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    clob_pair: _containers.RepeatedCompositeFieldContainer[_clob_pair_pb2.ClobPair]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, clob_pair: _Optional[_Iterable[_Union[_clob_pair_pb2.ClobPair, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class MevNodeToNodeCalculationRequest(_message.Message):
    __slots__ = ("block_proposer_matches", "validator_mev_metrics")
    BLOCK_PROPOSER_MATCHES_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_MEV_METRICS_FIELD_NUMBER: _ClassVar[int]
    block_proposer_matches: _mev_pb2.ValidatorMevMatches
    validator_mev_metrics: _mev_pb2.MevNodeToNodeMetrics
    def __init__(self, block_proposer_matches: _Optional[_Union[_mev_pb2.ValidatorMevMatches, _Mapping]] = ..., validator_mev_metrics: _Optional[_Union[_mev_pb2.MevNodeToNodeMetrics, _Mapping]] = ...) -> None: ...

class MevNodeToNodeCalculationResponse(_message.Message):
    __slots__ = ("results",)
    class MevAndVolumePerClob(_message.Message):
        __slots__ = ("clob_pair_id", "mev", "volume")
        CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
        MEV_FIELD_NUMBER: _ClassVar[int]
        VOLUME_FIELD_NUMBER: _ClassVar[int]
        clob_pair_id: int
        mev: float
        volume: int
        def __init__(self, clob_pair_id: _Optional[int] = ..., mev: _Optional[float] = ..., volume: _Optional[int] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[MevNodeToNodeCalculationResponse.MevAndVolumePerClob]
    def __init__(self, results: _Optional[_Iterable[_Union[MevNodeToNodeCalculationResponse.MevAndVolumePerClob, _Mapping]]] = ...) -> None: ...

class QueryEquityTierLimitConfigurationRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryEquityTierLimitConfigurationResponse(_message.Message):
    __slots__ = ("equity_tier_limit_config",)
    EQUITY_TIER_LIMIT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    equity_tier_limit_config: _equity_tier_limit_config_pb2.EquityTierLimitConfiguration
    def __init__(self, equity_tier_limit_config: _Optional[_Union[_equity_tier_limit_config_pb2.EquityTierLimitConfiguration, _Mapping]] = ...) -> None: ...

class QueryBlockRateLimitConfigurationRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryBlockRateLimitConfigurationResponse(_message.Message):
    __slots__ = ("block_rate_limit_config",)
    BLOCK_RATE_LIMIT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    block_rate_limit_config: _block_rate_limit_config_pb2.BlockRateLimitConfiguration
    def __init__(self, block_rate_limit_config: _Optional[_Union[_block_rate_limit_config_pb2.BlockRateLimitConfiguration, _Mapping]] = ...) -> None: ...

class QueryLiquidationsConfigurationRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryLiquidationsConfigurationResponse(_message.Message):
    __slots__ = ("liquidations_config",)
    LIQUIDATIONS_CONFIG_FIELD_NUMBER: _ClassVar[int]
    liquidations_config: _liquidations_config_pb2.LiquidationsConfig
    def __init__(self, liquidations_config: _Optional[_Union[_liquidations_config_pb2.LiquidationsConfig, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.cosmos.store.streaming.abci import grpc_pb2 as cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2


class ABCIListenerServiceStub(object):
    """ABCIListenerService is the service for the BaseApp ABCIListener interface
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListenFinalizeBlock = channel.unary_unary(
                '/cosmos.store.streaming.abci.ABCIListenerService/ListenFinalizeBlock',
                request_serializer=cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenFinalizeBlockRequest.SerializeToString,
                response_deserializer=cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenFinalizeBlockResponse.FromString,
                )
        self.ListenCommit = channel.unary_unary(
                '/cosmos.store.streaming.abci.ABCIListenerService/ListenCommit',
                request_serializer=cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenCommitRequest.SerializeToString,
                response_deserializer=cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenCommitResponse.FromString,
                )


class ABCIListenerServiceServicer(object):
    """ABCIListenerService is the service for the BaseApp ABCIListener interface
    """

    def ListenFinalizeBlock(self, request, context):
        """ListenFinalizeBlock is the corresponding endpoint for ABCIListener.ListenEndBlock
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListenCommit(self, request, context):
        """ListenCommit is the corresponding endpoint for ABCIListener.ListenCommit
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ABCIListenerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListenFinalizeBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.ListenFinalizeBlock,
                    request_deserializer=cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenFinalizeBlockRequest.FromString,
                    response_serializer=cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenFinalizeBlockResponse.SerializeToString,
            ),
            'ListenCommit': grpc.unary_unary_rpc_method_handler(
                    servicer.ListenCommit,
                    request_deserializer=cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenCommitRequest.FromString,
                    response_serializer=cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenCommitResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.store.streaming.abci.ABCIListenerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ABCIListenerService(object):
    """ABCIListenerService is the service for the BaseApp ABCIListener interface
    """

    @staticmethod
    def ListenFinalizeBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.store.streaming.abci.ABCIListenerService/ListenFinalizeBlock',
            cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenFinalizeBlockRequest.SerializeToString,
            cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenFinalizeBlockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListenCommit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.store.streaming.abci.ABCIListenerService/ListenCommit',
            cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenCommitRequest.SerializeToString,
            cosmos_dot_store_dot_streaming_dot_abci_dot_grpc__pb2.ListenCommitResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/delaymsg/block_message_ids.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-dydxprotocol/delaymsg/block_message_ids.proto\x12\x15\x64ydxprotocol.delaymsg\"\x1e\n\x0f\x42lockMessageIds\x12\x0b\n\x03ids\x18\x01 \x03(\rB<Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.delaymsg.block_message_ids_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/types'
  _globals['_BLOCKMESSAGEIDS']._serialized_start=72
  _globals['_BLOCKMESSAGEIDS']._serialized_end=102
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.dydxprotocol.bridge import tx_pb2 as dydxprotocol_dot_bridge_dot_tx__pb2


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AcknowledgeBridges = channel.unary_unary(
                '/dydxprotocol.bridge.Msg/AcknowledgeBridges',
                request_serializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgAcknowledgeBridges.SerializeToString,
                response_deserializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgAcknowledgeBridgesResponse.FromString,
                )
        self.CompleteBridge = channel.unary_unary(
                '/dydxprotocol.bridge.Msg/CompleteBridge',
                request_serializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgCompleteBridge.SerializeToString,
                response_deserializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgCompleteBridgeResponse.FromString,
                )
        self.UpdateEventParams = channel.unary_unary(
                '/dydxprotocol.bridge.Msg/UpdateEventParams',
                request_serializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateEventParams.SerializeToString,
                response_deserializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateEventParamsResponse.FromString,
                )
        self.UpdateProposeParams = channel.unary_unary(
                '/dydxprotocol.bridge.Msg/UpdateProposeParams',
                request_serializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateProposeParams.SerializeToString,
                response_deserializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateProposeParamsResponse.FromString,
                )
        self.UpdateSafetyParams = channel.unary_unary(
                '/dydxprotocol.bridge.Msg/UpdateSafetyParams',
                request_serializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateSafetyParams.SerializeToString,
                response_deserializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateSafetyParamsResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def AcknowledgeBridges(self, request, context):
        """AcknowledgeBridges acknowledges bridges and sets them to complete at a
        later block.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompleteBridge(self, request, context):
        """CompleteBridge finalizes a bridge by minting coins to an address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEventParams(self, request, context):
        """UpdateEventParams updates the EventParams in state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProposeParams(self, request, context):
        """UpdateProposeParams updates the ProposeParams in state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSafetyParams(self, request, context):
        """UpdateSafetyParams updates the SafetyParams in state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AcknowledgeBridges': grpc.unary_unary_rpc_method_handler(
                    servicer.AcknowledgeBridges,
                    request_deserializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgAcknowledgeBridges.FromString,
                    response_serializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgAcknowledgeBridgesResponse.SerializeToString,
            ),
            'CompleteBridge': grpc.unary_unary_rpc_method_handler(
                    servicer.CompleteBridge,
                    request_deserializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgCompleteBridge.FromString,
                    response_serializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgCompleteBridgeResponse.SerializeToString,
            ),
            'UpdateEventParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEventParams,
                    request_deserializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateEventParams.FromString,
                    response_serializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateEventParamsResponse.SerializeToString,
            ),
            'UpdateProposeParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProposeParams,
                    request_deserializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateProposeParams.FromString,
                    response_serializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateProposeParamsResponse.SerializeToString,
            ),
            'UpdateSafetyParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSafetyParams,
                    request_deserializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateSafetyParams.FromString,
                    response_serializer=dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateSafetyParamsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.bridge.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def AcknowledgeBridges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.bridge.Msg/AcknowledgeBridges',
            dydxprotocol_dot_bridge_dot_tx__pb2.MsgAcknowledgeBridges.SerializeToString,
            dydxprotocol_dot_bridge_dot_tx__pb2.MsgAcknowledgeBridgesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompleteBridge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.bridge.Msg/CompleteBridge',
            dydxprotocol_dot_bridge_dot_tx__pb2.MsgCompleteBridge.SerializeToString,
            dydxprotocol_dot_bridge_dot_tx__pb2.MsgCompleteBridgeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEventParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.bridge.Msg/UpdateEventParams',
            dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateEventParams.SerializeToString,
            dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateEventParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProposeParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.bridge.Msg/UpdateProposeParams',
            dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateProposeParams.SerializeToString,
            dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateProposeParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSafetyParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.bridge.Msg/UpdateSafetyParams',
            dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateSafetyParams.SerializeToString,
            dydxprotocol_dot_bridge_dot_tx__pb2.MsgUpdateSafetyParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.dydxprotocol.prices import query_pb2 as dydxprotocol_dot_prices_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.MarketPrice = channel.unary_unary(
                '/dydxprotocol.prices.Query/MarketPrice',
                request_serializer=dydxprotocol_dot_prices_dot_query__pb2.QueryMarketPriceRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_prices_dot_query__pb2.QueryMarketPriceResponse.FromString,
                )
        self.AllMarketPrices = channel.unary_unary(
                '/dydxprotocol.prices.Query/AllMarketPrices',
                request_serializer=dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketPricesRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketPricesResponse.FromString,
                )
        self.MarketParam = channel.unary_unary(
                '/dydxprotocol.prices.Query/MarketParam',
                request_serializer=dydxprotocol_dot_prices_dot_query__pb2.QueryMarketParamRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_prices_dot_query__pb2.QueryMarketParamResponse.FromString,
                )
        self.AllMarketParams = channel.unary_unary(
                '/dydxprotocol.prices.Query/AllMarketParams',
                request_serializer=dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketParamsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketParamsResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def MarketPrice(self, request, context):
        """Queries a MarketPrice by id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllMarketPrices(self, request, context):
        """Queries a list of MarketPrice items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarketParam(self, request, context):
        """Queries a MarketParam by id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllMarketParams(self, request, context):
        """Queries a list of MarketParam items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'MarketPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.MarketPrice,
                    request_deserializer=dydxprotocol_dot_prices_dot_query__pb2.QueryMarketPriceRequest.FromString,
                    response_serializer=dydxprotocol_dot_prices_dot_query__pb2.QueryMarketPriceResponse.SerializeToString,
            ),
            'AllMarketPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.AllMarketPrices,
                    request_deserializer=dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketPricesRequest.FromString,
                    response_serializer=dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketPricesResponse.SerializeToString,
            ),
            'MarketParam': grpc.unary_unary_rpc_method_handler(
                    servicer.MarketParam,
                    request_deserializer=dydxprotocol_dot_prices_dot_query__pb2.QueryMarketParamRequest.FromString,
                    response_serializer=dydxprotocol_dot_prices_dot_query__pb2.QueryMarketParamResponse.SerializeToString,
            ),
            'AllMarketParams': grpc.unary_unary_rpc_method_handler(
                    servicer.AllMarketParams,
                    request_deserializer=dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketParamsRequest.FromString,
                    response_serializer=dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketParamsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.prices.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def MarketPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.prices.Query/MarketPrice',
            dydxprotocol_dot_prices_dot_query__pb2.QueryMarketPriceRequest.SerializeToString,
            dydxprotocol_dot_prices_dot_query__pb2.QueryMarketPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AllMarketPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.prices.Query/AllMarketPrices',
            dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketPricesRequest.SerializeToString,
            dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketPricesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarketParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.prices.Query/MarketParam',
            dydxprotocol_dot_prices_dot_query__pb2.QueryMarketParamRequest.SerializeToString,
            dydxprotocol_dot_prices_dot_query__pb2.QueryMarketParamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AllMarketParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.prices.Query/AllMarketParams',
            dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketParamsRequest.SerializeToString,
            dydxprotocol_dot_prices_dot_query__pb2.QueryAllMarketParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
